@@ -3,6 +3,8 @@ from .agora_base import *
 from .local_user import *
 import ctypes
 from .audio_frame_observer import *
+import logging
+logger = logging.getLogger(__name__)
 
 
 class AudioFrameInner(ctypes.Structure):
@@ -73,31 +75,31 @@ class AudioFrameObserverInner(ctypes.Structure):
         # self.on_get_ear_monitoring_audio_frame_param = ON_GET_EAR_MONITORING_AUDIO_FRAME_PARAM_CALLBACK(self._on_get_ear_monitoring_audio_frame_param)
 
     def _on_record_audio_frame(self, local_user_handle, channel_id, audio_frame_inner):
-        # print("AudioFrameObserverInner _on_record_audio_frame", local_user_handle, channel_id, audio_frame_inner)
+        logger.debug(f"AudioFrameObserverInner _on_record_audio_frame: {local_user_handle}, {channel_id}, {audio_frame_inner}")
         channel_id_str = channel_id.decode('utf-8')
         frame = audio_frame_inner.contents._to_audio_frame()
         ret = self.observer.on_record_audio_frame(self.local_user, channel_id_str, frame)
         return ret
 
     def _on_playback_audio_frame(self, local_user_handle, channel_id, audio_frame_inner):
-        # print("AudioFrameObserverInner _on_playback_audio_frame", local_user_handle, channel_id, audio_frame_inner)
+        logger.debug(f"AudioFrameObserverInner _on_playback_audio_frame: {local_user_handle}, {channel_id}, {audio_frame_inner}")
         channel_id_str = channel_id.decode('utf-8')
         frame = audio_frame_inner.contents._to_audio_frame()
         ret = self.observer.on_playback_audio_frame(self.local_user, channel_id_str, frame)
         return ret
 
     def _on_mixed_audio_frame(self, local_user_handle, channel_id, audio_frame_inner):
-        # print("AudioFrameObserverInner _on_mixed_audio_frame", local_user_handle, channel_id, audio_frame_inner)
+        logger.debug(f"AudioFrameObserverInner _on_mixed_audio_frame: {local_user_handle}, {channel_id}, {audio_frame_inner}")
         ret = self.observer.on_mixed_audio_frame(self.local_user, audio_frame_inner)
         return ret
 
     def _on_ear_monitoring_audio_frame(self, local_user_handle, audio_frame_inner):
-        # print("AudioFrameObserverInner _on_ear_monitoring_audio_frame", local_user_handle, audio_frame_inner)
+        logger.debug(f"AudioFrameObserverInner _on_ear_monitoring_audio_frame: {local_user_handle}, {audio_frame_inner}")
         ret = self.observer.on_ear_monitoring_audio_frame(self.local_user, audio_frame_inner)
         return ret
 
     def _on_playback_audio_frame_before_mixing(self, local_user_handle, channel_id, user_id, audio_frame_inner):
-        # print("AudioFrameObserverInner _on_playback_audio_frame_before_mixing", local_user_handle, channel_id, user_id, audio_frame_inner)
+        logger.debug(f"AudioFrameObserverInner _on_playback_audio_frame_before_mixing: {local_user_handle}, {channel_id}, {user_id}, {audio_frame_inner}")
         if channel_id is None:
             channel_id_str = ""
         else:
@@ -109,12 +111,12 @@ class AudioFrameObserverInner(ctypes.Structure):
         return ret
     
     def _on_get_audio_frame_position(self, local_user_handle):
-        # print("AudioFrameObserverInner _on_get_audio_frame_position", local_user_handle)
+        logger.debug(f"AudioFrameObserverInner _on_get_audio_frame_position: {local_user_handle}")
         return 0
         return self.observer.on_get_audio_frame_position(self.local_user)
 
     def _on_get_playback_audio_frame_param(self, local_user_handle):
-        # print("AudioFrameObserverInner _on_get_playback_audio_frame_param", local_user_handle)
+        logger.debug(f"AudioFrameObserverInner _on_get_playback_audio_frame_param: {local_user_handle}")
         params = AudioParams()
         params.sample_rate = 16000  # 示例值
         params.channels = 1          # 示例值
@@ -124,7 +126,7 @@ class AudioFrameObserverInner(ctypes.Structure):
         return self.observer.on_get_playback_audio_frame_param(self.local_user)
 
     def _on_get_record_audio_frame_param(self, local_user_handle):
-        # print("AudioFrameObserverInner _on_get_record_audio_frame_param", local_user_handle)
+        logger.debug(f"AudioFrameObserverInner _on_get_record_audio_frame_param: {local_user_handle}")
         params = AudioParams()
         params.sample_rate = 16000  # 示例值
         params.channels = 1          # 示例值
@@ -134,7 +136,7 @@ class AudioFrameObserverInner(ctypes.Structure):
         return self.observer.on_get_record_audio_frame_param(self.local_user)
 
     def _on_get_mixed_audio_frame_param(self, local_user_handle):
-        # print("AudioFrameObserverInner _on_get_mixed_audio_frame_param", local_user_handle)
+        logger.debug(f"AudioFrameObserverInner _on_get_mixed_audio_frame_param: {local_user_handle}")
         params = AudioParams()
         params.sample_rate = 16000  # 示例值
         params.channels = 1          # 示例值
@@ -144,7 +146,7 @@ class AudioFrameObserverInner(ctypes.Structure):
         return self.observer.on_get_mixed_audio_frame_param(self.local_user)
 
     def _on_get_ear_monitoring_audio_frame_param(self, local_user_handle):
-        # print("AudioFrameObserverInner _on_get_ear_monitoring_audio_frame_param", local_user_handle)
+        logger.debug(f"AudioFrameObserverInner _on_get_ear_monitoring_audio_frame_param: {local_user_handle}")
         params = AudioParams()
         params.sample_rate = 16000  # 示例值
         params.channels = 1          # 示例值
