@@ -9,7 +9,8 @@ from .local_audio_track import *
 from .rtc_connection_observer import *
 from .video_frame_sender import *
 from .local_video_track import *
-
+import logging
+logger = logging.getLogger(__name__)
 class AgoraServiceConfig(ctypes.Structure):
     def __init__(
             self,
@@ -150,7 +151,7 @@ class AgoraService:
         result = agora_service_initialize(self.service_handle, ctypes.byref(config._to_inner()))
         if result == 0:
             self.inited = True
-        print(f'Initialization result: {result}')
+        logger.debug(f'Initialization result: {result}')
 
         if config.log_path:
             log_size = 512 * 1024
@@ -174,7 +175,7 @@ class AgoraService:
     #createMediaNodeFactory	创建一个媒体节点工厂对象。
     def create_media_node_factory(self):
         if not self.inited:
-            print("AgoraService is not initialized. Please call initialize() first.")
+            logger.error("AgoraService is not initialized. Please call initialize() first.")
             return None
         media_node_handle = agora_service_create_media_node_factory(self.service_handle)
         if media_node_handle is None:
@@ -184,7 +185,7 @@ class AgoraService:
 
     def create_rtc_connection(self, con_config: RTCConnConfig):       
         if not self.inited:
-            print("AgoraService is not initialized. Please call initialize() first.")
+            logger.error("AgoraService is not initialized. Please call initialize() first.")
             return None
         rtc_conn_handle = agora_rtc_conn_create(self.service_handle, ctypes.byref(con_config._to_inner()))
         if rtc_conn_handle is None:
@@ -195,7 +196,7 @@ class AgoraService:
     #createCustomAudioTrackPcm	创建一个自定义音频Track。
     def create_custom_audio_track_pcm(self, audio_pcm_data_sender:AudioPcmDataSender):
         if not self.inited:
-            print("AgoraService is not initialized. Please call initialize() first.")
+            logger.error("AgoraService is not initialized. Please call initialize() first.")
             return None
         custom_audio_track = agora_service_create_custom_audio_track_pcm(self.service_handle, audio_pcm_data_sender.sender_handle)
         if custom_audio_track is None:
@@ -204,7 +205,7 @@ class AgoraService:
     #mix_mode: MIX_ENABLED = 0, MIX_DISABLED = 1
     def create_custom_audio_track_encoded(self, audio_encoded_frame_sender:AudioEncodedFrameSender, mix_mode:int):
         if not self.inited:
-            print("AgoraService is not initialized. Please call initialize() first.")
+            logger.error("AgoraService is not initialized. Please call initialize() first.")
             return None
         custom_audio_track = agora_service_create_custom_audio_track_encoded(self.service_handle, audio_encoded_frame_sender.sender_handle, mix_mode)
         if custom_audio_track is None:
@@ -213,7 +214,7 @@ class AgoraService:
     
     def create_custom_video_track_frame(self, video_frame_sender:VideoFrameSender):
         if not self.inited:
-            print("AgoraService is not initialized. Please call initialize() first.")
+            logger.error("AgoraService is not initialized. Please call initialize() first.")
             return None
         custom_video_track = agora_service_create_custom_video_track_frame(self.service_handle, video_frame_sender.sender_handle)
         if custom_video_track is None:
@@ -222,7 +223,7 @@ class AgoraService:
     
     def create_custom_video_track_encoded(self, video_encoded_frame_sender:VideoEncodedImageSender, options:SenderOptions):
         if not self.inited:
-            print("AgoraService is not initialized. Please call initialize() first.")
+            logger.error("AgoraService is not initialized. Please call initialize() first.")
             return None
         custom_video_track = agora_service_create_custom_video_track_encoded(self.service_handle, video_encoded_frame_sender.sender_handle, ctypes.byref(options))
         if custom_video_track is None:
@@ -231,14 +232,14 @@ class AgoraService:
     
     def set_log_file(self, log_path: str, log_size: int = 512 * 1024):
         if not self.inited:
-            print("AgoraService is not initialized. Please call initialize() first.")
+            logger.error("AgoraService is not initialized. Please call initialize() first.")
             return -1
         encoded_log_path = log_path.encode('utf-8')
         result = agora_service_set_log_file(self.service_handle, ctypes.create_string_buffer(encoded_log_path), log_size)
         if result == 0:
-            print(f"Log file set successfully: {log_path}")
+            logger.debug(f"Log file set successfully: {log_path}")
         else:
-            print(f"Failed to set log file. Error code: {result}")
+            logger.error(f"Failed to set log file. Error code: {result}")
         return result
 
 
